@@ -66,7 +66,7 @@ sub find {
     my $self = shift;
     my %params = @_;
 
-    return $self->client()->get("/profiles/v2/search/jobs", %params);
+    die "The legacy API was deprecated. Please, use GraphQL call - see example in this library.";
 }
 
 =back
